==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/GetEnvironmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName The name of the environment.
 * @property environmentSettingName The name of the environment Setting.
 * @property expand Specify the $expand query. Example: 'properties($expand=networkInterface)'
 * @property labAccountName The name of the lab Account.
 * @property labName The name of the lab.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetEnvironmentPlainArgs(
    public val environmentName: String,
    public val environmentSettingName: String,
    public val expand: String? = null,
    public val labAccountName: String,
    public val labName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs =
        com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .environmentSettingName(environmentSettingName.let({ args0 -> args0 }))
            .expand(expand?.let({ args0 -> args0 }))
            .labAccountName(labAccountName.let({ args0 -> args0 }))
            .labName(labName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetEnvironmentPlainArgs].
 */
@PulumiTagMarker
public class GetEnvironmentPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var environmentSettingName: String? = null

    private var expand: String? = null

    private var labAccountName: String? = null

    private var labName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the environment.
     */
    @JvmName("ohxwgkptnvmofrkm")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value The name of the environment Setting.
     */
    @JvmName("knavgfmbxmahdyyn")
    public suspend fun environmentSettingName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentSettingName = mapped
    }

    /**
     * @param value Specify the $expand query. Example: 'properties($expand=networkInterface)'
     */
    @JvmName("lkjnbbbupthiwswc")
    public suspend fun expand(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.expand = mapped
    }

    /**
     * @param value The name of the lab Account.
     */
    @JvmName("kfjaftxarelqkvbi")
    public suspend fun labAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labAccountName = mapped
    }

    /**
     * @param value The name of the lab.
     */
    @JvmName("gnteomeudceqaqvx")
    public suspend fun labName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("fbvwpqvhqblaywdn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetEnvironmentPlainArgs = GetEnvironmentPlainArgs(
        environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
        environmentSettingName = environmentSettingName ?: throw
            PulumiNullFieldException("environmentSettingName"),
        expand = expand,
        labAccountName = labAccountName ?: throw PulumiNullFieldException("labAccountName"),
        labName = labName ?: throw PulumiNullFieldException("labName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/GetEnvironmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName The name of the environment.
 * @property environmentSettingName The name of the environment Setting.
 * @property expand Specify the $expand query. Example: 'properties($expand=networkInterface)'
 * @property labAccountName The name of the lab Account.
 * @property labName The name of the lab.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetEnvironmentPlainArgs(
    public val environmentName: String,
    public val environmentSettingName: String,
    public val expand: String? = null,
    public val labAccountName: String,
    public val labName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs =
        com.pulumi.azurenative.labservices.inputs.GetEnvironmentPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .environmentSettingName(environmentSettingName.let({ args0 -> args0 }))
            .expand(expand?.let({ args0 -> args0 }))
            .labAccountName(labAccountName.let({ args0 -> args0 }))
            .labName(labName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetEnvironmentPlainArgs].
 */
@PulumiTagMarker
public class GetEnvironmentPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var environmentSettingName: String? = null

    private var expand: String? = null

    private var labAccountName: String? = null

    private var labName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the environment.
     */
    @JvmName("krixkcsotksivapo")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value The name of the environment Setting.
     */
    @JvmName("oojeypopiuuaysmh")
    public suspend fun environmentSettingName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentSettingName = mapped
    }

    /**
     * @param value Specify the $expand query. Example: 'properties($expand=networkInterface)'
     */
    @JvmName("kykrvwfvmqpffuyy")
    public suspend fun expand(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.expand = mapped
    }

    /**
     * @param value The name of the lab Account.
     */
    @JvmName("yltxispwahkrusyt")
    public suspend fun labAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labAccountName = mapped
    }

    /**
     * @param value The name of the lab.
     */
    @JvmName("qwlyxxkvakdgihne")
    public suspend fun labName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("paqyqtpvugsdgkee")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetEnvironmentPlainArgs = GetEnvironmentPlainArgs(
        environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
        environmentSettingName = environmentSettingName ?: throw
            PulumiNullFieldException("environmentSettingName"),
        expand = expand,
        labAccountName = labAccountName ?: throw PulumiNullFieldException("labAccountName"),
        labName = labName ?: throw PulumiNullFieldException("labName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
